<?php

/* コンテンツ幅、標準styleにも1か所 */
function pure_width() {
	$GLOBALS['content_width'] = apply_filters( 'pure_width', 1200 );
}
add_action( 'after_setup_theme', 'pure_width', 0 );
/**
 * Theme Setup
 */
if ( ! function_exists( 'pureframe_setup' ) ) :
function pureframe_setup() {

	// This theme styles the visual editor to resemble the theme style.
	add_editor_style( array( 'css/editor-style.css' ) );

	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'top-menu'   => __( 'Top main menu', 'pureframe' ),
		'footer-menu' => __( 'footer menu', 'pureframe' ),
	) );

	/* コメントフォーム、検索フォーム、コメントリスト、ギャラリーでHTML5マークアップの使用を許可 */
add_theme_support( 'html5', array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption' ) );

	/* 投稿サムネイルをサポート*/
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 1200, 9999 );


	add_theme_support( 'custom-header', array(
		'flex-width'    => true,
		'width'         => 1200,
		'flex-width'    => true,
		'height'        => 900,
		'video'         => true,
		'default-image' => get_template_directory_uri() . '/img/default-image.jpg',
	) );

    add_theme_support( 'custom-logo', array(
        'height'      => 248,
        'width'       => 248,
        'flex-height' => true,
    ) );
/* 投稿とコメントのRSSフィードのリンクを有効 */
    add_theme_support( 'automatic-feed-links' );
    add_theme_support( 'title-tag' );

/* 固定ページで抜粋の機能を有効化 */
add_post_type_support( 'page', 'excerpt' );
/* カスタマイザーで背景色設定 */
add_theme_support('custom-background');

}
endif; 
add_action( 'after_setup_theme', 'pureframe_setup' );

/* widgetでショートコードを有効にする */
add_filter( 'widget_text', 'do_shortcode' );

/* 多言語化（暫定） */
load_theme_textdomain( 'pureframe', get_template_directory() . '/languages' );

/* カスタム投稿タイプを追加 */
function custom_post_type() {
    register_post_type( 'private_blog',
        array(
			'labels' => array(
				'name' => 'ブログ',
				'menu_name' => 'ブログ',
			),
            'public'        => true,
            'exclude_from_search' => false,
            'show_ui' => true,
            'show_in_menu' => true,
            'menu_position' => 5,
            'has_archive'   => true,
            'supports' => array(
                'title',
                'editor',
                'comments',
                'excerpt',
				'author',
                'revisions',
            ),
            'rewrite' => true,
			'capability' => 'post',
        )
    );
}
add_action( 'init', 'custom_post_type');

/* CSS & Script Header Entry */
function pureframe_scripts() {
?>
<script src="//use.fontawesome.com/f230347e8a.js" async></script>
<?php if (!empty(get_facebook_appid())) {?><script src="//connect.facebook.net/en_US/sdk.js#xfbml=1&version=v2.10&appId=<?php echo get_facebook_appid(); ?>" id="facebook-jssdk" defer></script>
<?php };;}
add_action( 'wp_enqueue_scripts', 'pureframe_scripts' );

function pureframe_cdn() { 
/* <link rel="stylesheet" href="//cdn.jsdelivr.net/combine/npm/purecss@1.0.0/build/pure-min.css,npm/purecss@1.0.0/build/grids-responsive-min.css" />  */
if ( file_exists(get_template_directory().'/style.min.css') ): ?>
	<style type="text/css"><?php include ( get_template_directory() . '/css/pure-min.css') ; include ( get_template_directory() . '/css/grids-responsive-min.css'); ; include ( get_template_directory() . '/style-min.css'); ?></style>
<?php else : ?>
	<style type="text/css"><?php include ( get_template_directory() . '/css/pure-min.css') ; include ( get_template_directory() . '/css/grids-responsive-min.css'); ; include ( get_template_directory() . '/style.css'); ?></style>
<?php endif;
 }

function pureframe_sanitize_checkbox( $checked ) {
    return ( ( isset( $checked ) && true == $checked ) ? true : false );
}
function pureframe_sanitize_image( $image, $setting ) {
    $mimes = array(
        'jpg|jpeg|jpe' => 'image/jpeg',
        'gif'          => 'image/gif',
        'png'          => 'image/png',
        'bmp'          => 'image/bmp',
        'tif|tiff'     => 'image/tiff',
        'ico'          => 'image/x-icon'
    );
    $file = wp_check_filetype( $image, $mimes );
    return ( $file['ext'] ? $image : $setting->default );
}
function pureframe_customize_register( $wp_customize ) {
  $wp_customize->add_section( 'pureframe_origin_scheme', array(
    'title'     => 'テーマオプション',
    'priority'  => 200,
  ));
  $wp_customize->add_setting( 'pureframe_options_telephone_num', array(
    'default'   => '',
    'type'      => 'option',
    'transport' => 'postMessage',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'pureframe_options_telephone_num', array(
    'settings'  => 'pureframe_options_telephone_num',
    'label'     => '電話番号',
    'section'   => 'pureframe_origin_scheme',
    'type'      => 'text',
	'description' => '「-」は入れず、数字のみ入力',
  ));
  $wp_customize->add_setting( 'pureframe_options_business_hours', array(
    'default'   => '',
    'type'      => 'option',
    'transport' => 'postMessage',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'pureframe_options_business_hours', array(
    'settings'  => 'pureframe_options_business_hours',
    'label'     => '営業時間',
    'section'   => 'pureframe_origin_scheme',
    'type'      => 'text',
  ));
$wp_customize->add_setting( 'pureframe_options_contact_checkbox', array(
  'default'   => false,
  'type'      => 'option',
  'transport' => 'refresh',
    'sanitize_callback' => 'pureframe_sanitize_checkbox',
));
$wp_customize->add_control( 'pureframe_options_contact_checkbox', array(
  'settings'  => 'pureframe_options_contact_checkbox',
  'label'     => 'ヘッダーコンタクトを表示する',
  'section'   => 'pureframe_origin_scheme',
  'type'      => 'checkbox',
));
  $wp_customize->add_setting( 'pureframe_options_copyright_site', array(
    'default'   => '',
    'type'      => 'option',
    'transport' => 'postMessage',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'pureframe_options_copyright_site', array(
    'settings'  => 'pureframe_options_copyright_site',
    'label'     => 'Copyrightのサイト名',
    'section'   => 'pureframe_origin_scheme',
    'type'      => 'text',
	'description' => '空白の場合、サイト名を表示',
  ));
  $wp_customize->add_setting( 'pureframe_options_bottom_guide', array(
    'default'   => '',
    'type'      => 'option',
    'transport' => 'postMessage',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'pureframe_options_bottom_guide', array(
    'settings'  => 'pureframe_options_bottom_guide',
    'label'     => 'サイト概要（最下部に表示）',
    'section'   => 'pureframe_origin_scheme',
    'type'      => 'textarea',
  ));
$wp_customize->add_setting( 'pureframe_options_theme_checkbox', array(
  'default'   => false,
  'type'      => 'option',
  'transport' => 'refresh',
    'sanitize_callback' => 'pureframe_sanitize_checkbox',
));
$wp_customize->add_control( 'pureframe_options_theme_checkbox', array(
  'settings'  => 'pureframe_options_theme_checkbox',
  'label'     => 'フッターにテーマ名を表示しない',
  'section'   => 'pureframe_origin_scheme',
  'type'      => 'checkbox',
));
  $wp_customize->add_setting('ogp_image_url', array(
    'default'   => '',
    'type' => 'option',
    'sanitize_callback' => 'pureframe_sanitize_image',
  ));
  $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'ogp_image_url', array(
    'settings' => 'ogp_image_url',
    'label' => 'OGP画像',
    'section' => 'pureframe_origin_scheme',
	'description' => 'Facebook/Twitterでサムネイル画像がない場合に表示されます。1200px × 630px推奨',
  )));
  $wp_customize->add_setting( 'pureframe_options_facebook_appid', array(
    'default'   => '',
    'type'      => 'option',
    'transport' => 'postMessage',
    'sanitize_callback' => 'absint',
  ));
  $wp_customize->add_control( 'pureframe_options_facebook_appid', array(
    'settings'  => 'pureframe_options_facebook_appid',
    'label'     => 'Fcaebook App-ID(15桁)',
    'section'   => 'pureframe_origin_scheme',
    'type'      => 'text',
	'description' => 'FacebookのApp-ID。 OGP表示とFacebook page表示のsdk.jsの読込みをする。',
  ));
  $wp_customize->add_setting( 'pureframe_options_twitter_id', array(
    'default'   => '',
    'type'      => 'option',
    'transport' => 'postMessage',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'pureframe_options_twitter_id', array(
    'settings'  => 'pureframe_options_twitter_id',
    'label'     => 'Twitter ID @',
    'section'   => 'pureframe_origin_scheme',
    'type'      => 'text',
	'description' => 'Twitter OGP表示には必須',
  ));
  $wp_customize->add_setting( 'pureframe_options_tracking_id', array(
    'default'   => '',
    'type'      => 'option',
    'transport' => 'postMessage',
    'sanitize_callback' => 'sanitize_text_field',
  ));
  $wp_customize->add_control( 'pureframe_options_tracking_id', array(
    'settings'  => 'pureframe_options_tracking_id',
    'label'     => 'トラッキング ID',
    'section'   => 'pureframe_origin_scheme',
    'type'      => 'text',
	'description' => 'Google アナリティクス 「UA-XXXXXXXX-YY」',
  ));
}
add_action( 'customize_register', 'pureframe_customize_register' );
/* OGP情報の設定 */
function get_ogp_image_url(){
  return esc_url( get_option( 'ogp_image_url' ) );
}
function get_facebook_appid(){
  return esc_html( get_option( 'pureframe_options_facebook_appid' ) );
}
function get_twitter_id(){
  return esc_html( get_option( 'pureframe_options_twitter_id' ) );
}
/* サイト最下部表示情報 */
function get_copyright_site(){
  return esc_html( get_option('pureframe_options_copyright_site') );
}
function get_bottom_guide(){
  return esc_html( get_option('pureframe_options_bottom_guide') );
}
/* Google アナリティクス トラッキング ID */
function get_analytics_id(){
  return esc_html( get_option('pureframe_options_tracking_id') );
}


/* ウィジェット */
function pureframe_widgets_init() {

register_sidebar( array(
     'name' => __( 'トップスライドショー' , 'pureframe' ),
     'id' => 'front-slide-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<aside>',
     'after_title' => '</aside>',
) );
register_sidebar( array(
     'name' => __( 'トップメニュー下' , 'pureframe' ),
     'id' => 'front-top-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( 'トップコンテンツ' , 'pureframe' ),
     'id' => 'front-bottom-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( 'トップ左上側' , 'pureframe' ),
     'id' => 'front-left-top-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( 'トップ左下側' , 'pureframe' ),
     'id' => 'front-left-bottom-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( 'トップ右サイド' , 'pureframe' ),
     'id' => 'front-right-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( 'トップ下左' , 'pureframe' ),
     'id' => 'front-bottom-left-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( 'トップ下右' , 'pureframe' ),
     'id' => 'front-bottom-right-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );

register_sidebar( array(
     'name' => __( '固定ページメニュー下' , 'pureframe' ),
     'id' => 'page-content-top-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( '固定ページコンテンツ' , 'pureframe' ),
     'id' => 'page-content-bottom-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( '固定左上側' , 'pureframe' ),
     'id' => 'page-left-top-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( '固定左下側' , 'pureframe' ),
     'id' => 'page-left-bottom-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( '固定右サイド' , 'pureframe' ),
     'id' => 'page-right-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( '固定下左' , 'pureframe' ),
     'id' => 'page-bottom-left-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( '固定下右' , 'pureframe' ),
     'id' => 'page-bottom-right-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( '投稿ページコンテンツ上' , 'pureframe' ),
     'id' => 'post-content-top-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( '投稿ページコンテンツ下' , 'pureframe' ),
     'id' => 'post-content-bottom-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( '投稿左上側' , 'pureframe' ),
     'id' => 'post-left-top-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( '投稿左下側' , 'pureframe' ),
     'id' => 'post-left-bottom-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( '投稿右サイド' , 'pureframe' ),
     'id' => 'post-right-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( '投稿下左' , 'pureframe' ),
     'id' => 'post-bottom-left-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( '投稿下右' , 'pureframe' ),
     'id' => 'post-bottom-right-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( 'フッター左' , 'pureframe' ),
     'id' => 'footer-left-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( 'フッター中央' , 'pureframe' ),
     'id' => 'footer-middle-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( 'フッター右' , 'pureframe' ),
     'id' => 'footer-right-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( '1カラム上側' , 'pureframe' ),
     'id' => '1col-top-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
register_sidebar( array(
     'name' => __( '1カラム下側' , 'pureframe' ),
     'id' => '1col-bottom-widget',
     'before_widget' => '<div id="%1$s" class="widget-container">',
     'after_widget' => '</div>',
     'before_title' => '<h3>',
     'after_title' => '</h3>',
) );
}
add_action( 'widgets_init', 'pureframe_widgets_init' );

 
/* nav menu for pure.css */
//setup menu
// Add custom class to li of wp_navi_menu()
add_filter('nav_menu_css_class' , 'special_nav_class' , 10 , 2);

function special_nav_class($classes, $item){
     $classes[] = "pure-menu-item";
     return $classes;
}
// Add class to a href
function add_menuclass($ulclass) {
 return preg_replace('/<a /', '<a class="pure-menu-link" ', $ulclass);
 }
add_filter('wp_nav_menu','add_menuclass');
// LI Submenu parent class
add_filter( 'wp_nav_menu_objects', 'add_menu_parent_class' );
function add_menu_parent_class( $items ) {
    
    $parents = array();
    foreach ( $items as $item ) {
        if ( $item->menu_item_parent && $item->menu_item_parent > 0 ) {
            $parents[] = $item->menu_item_parent;
        }
    }
    foreach ( $items as $item ) {
        if ( in_array( $item->ID, $parents ) ) {
				$item->classes[] = 'pure-menu-item pure-menu-has-children pure-menu-allow-hover'; 
        }
    }
    return $items;
}
// Add class to ul submenu 
class pureframe_walker_nav_menu extends Walker_Nav_Menu {
// add classes to ul sub-menus
function start_lvl( &$output, $depth = 0, $args = array() ) {
    // depth dependent classes
    $indent = ( $depth > 0  ? str_repeat( "\t", $depth ) : '' ); // code indent
    $display_depth = ( $depth + 1); // because it counts the first submenu as 0
    $classes = array(
        'sub-menu pure-menu-children',
        ( $display_depth % 2  ? 'menu-odd' : 'menu-even' ),
        ( $display_depth >=2 ? 'sub-sub-menu' : '' ),
        'menu-depth-' . $display_depth
        );
    $class_names = implode( ' ', $classes );
    // build html
    $output .= "\n" . $indent . '<ul class="' . $class_names . '">' . "\n";
}
}


/* パンくずリスト */
function breadcrumb(){
    global $post;
    $str = '';
    $ancestors = '';
        $a1h = '<li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem"><a itemprop="item" href="';
        $a1 = '<li class="pureframe-non-home" itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem"><a itemprop="item" href="';
        $a2 = '"><span itemprop="name">';
        $a3 = '</span></a><meta itemprop="position" content="';
        $b1 = '<li class="pureframe-non-home" itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem"><span itemprop="name">';
        $b2 = '</span><meta itemprop="position" content="';
    if(!is_home()&&!is_admin()){ /* 管理ページ以外 */
        $str.= '<nav id="breadcrumb"><ol itemscope itemtype="http://schema.org/BreadcrumbList">';
        $str.= $a1h . home_url() . $a2 . 'HOME' . $a3 . '1" /></li>';
        if(is_category()) {                             //カテゴリーページ
            $cat = get_queried_object();
            if($cat -> parent != 0){
                $ancestors = array_reverse(get_ancestors( $cat -> cat_ID, 'category' ));
                                $positionNum = 2;
                foreach($ancestors as $ancestor){
                                        $str.= $a1 . get_category_link($ancestor) . $a2 .get_cat_name($ancestor) . $a3 . $positionNum . '" /></li>';
                                        $positionNum++;
                }
            }
                        $position = count($ancestors)+2;
            $str.= $b1 . $cat -> name . $b2 . $position . '" /></li>';
        } elseif(is_single()){                          //個別記事ページ
            $categories = get_the_category($post->ID);
			if($categories != null){
				$cat = $categories[0];
				if($cat -> parent != 0){
					$ancestors = array_reverse(get_ancestors( $cat -> cat_ID, 'category' ));
					$positionNum = 2;
					foreach($ancestors as $ancestor){
					$str.= $a1 . get_category_link($ancestor) . $a2 . get_cat_name($ancestor) . $a3 . $positionNum . '" /></li>';
									$positionNum++;
					}
				}
					$position = count($ancestors)+2;
					$str.= $a1 . get_category_link($cat -> term_id). $a2 . $cat-> cat_name . $a3 . $position . '" /></li>';
			}
                        $position = count($ancestors)+3;
            $str.= $b1 . $post -> post_title . $b2 . $position.'" /></li>';
        } elseif(is_page()){                            //固定ページ
            if($post -> post_parent != 0 ){
                $ancestors = array_reverse(get_post_ancestors( $post->ID ));
                                $positionNum = 2;
                foreach($ancestors as $ancestor){
                    $str.= $a1 . get_permalink($ancestor) . $a2 . get_the_title($ancestor) . $a3 . $positionNum . '" /></li>';
                                        $positionNum++;
                }
            }
                        $position = count($ancestors)+2;
            $str.= $b1 . $post -> post_title . $b2 . $position.'" /></li>';
        } elseif(is_date()){                            //日付ベースのアーカイブページ
            if(get_query_var('day') != 0){              //年月日別アーカイブ
            $str.= $a1 . get_year_link(get_query_var('year')). $a2 . get_query_var('year') . '年' . $a3 . '2" /></li>';
                $str.= $a1 . get_month_link(get_query_var('year'), get_query_var('monthnum')). $a2 . get_query_var('monthnum') . '月' . $a3 . '3" /></li>';
                $str.= $b1 . get_query_var('day'). '日' . $b2 . '4" />';
            } elseif(get_query_var('monthnum') != 0){   //年月別アーカイブ
                $str.= $a1 . get_year_link(get_query_var('year')) . $a2 . get_query_var('year') .'年' . $a3 . '2" /></li>';
                $str.= $b1 . get_query_var('monthnum') . '月' . $b2 . '3" />';
            } else {                                     //年別アーカイブ
                $str.= $b1 . get_query_var('year') . '年' .  $b2 . '2" />';
            }
                        $str.= '</li>';
        } else {                                                                         //上記以外
             if(is_search()) {                                          //検索結果表示ページ                    
                        $str.= $b1 . '「'. get_search_query() .'」で検索した結果';
			}elseif(is_author()){                           //投稿者のアーカイブページ
                        $str.= $b1 . '投稿者 : '. get_the_author_meta('display_name', get_query_var('author'));
			} elseif(is_tag()){                             //タグのアーカイブページ
                        $str.= $b1 . 'タグ : '. single_tag_title( '' , false );
			} elseif(is_attachment()){                      //添付ファイルページ
						$str.= $b1 . $post -> post_title;
			} elseif(is_404()){                             //404 Not Found ページ
                        $str.= $b1 . '404 Not found';                  
			} else{                                     //その他
						$str.= $b1 . wp_title('', false) ;
			}
				$str.= $b2  . '2" /></li>';
        }
        $str.= '</ol>';
        $str.= '</nav>';
    }
    echo $str;
}

function pureframe_wp_title( $title, $sep ) {
	global $paged, $page;
	if ( is_feed() ) {
		return $title;
	}
	// Add the site name.
	$title .= get_bloginfo( 'name' );
	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) ) {
		$title = "$title $sep $site_description";
	}
	// Add a page number if necessary.
	if ( $paged >= 2 || $page >= 2 ) {
		$title = "$title $sep " . sprintf( __( 'Page %s', 'pureframe' ), max( $paged, $page ) );
	}
	return $title;
}
add_filter( 'wp_title', 'pureframe_wp_title', 10, 2 );

function custom_archive_title( $title ){
    if ( is_tax() ) {
        $title = single_term_title( '', false );
    }
    return $title;
}
add_filter( 'get_the_archive_title', 'custom_archive_title', 10 );

function pureframe_description() {
    global $paged;
	$metadescription_pages = '';
    if ( $paged != '0'){
        $metadescription_pages = '['.sprintf('Page of %s',$paged).'] '.$metadescription_pages;
    }
 ?>
<meta name="description" content="<?php if ( is_front_page() ) {
		$post_excerpt = strip_tags(get_the_excerpt());
		if (mb_strlen($post_excerpt)>30) {
			echo $post_excerpt;
		} else {
			bloginfo('name'); echo " : "; single_post_title('', true); echo " - "; bloginfo('description');
		}
	} elseif ( is_page() || is_single() ) {
		$post_excerpt = strip_tags(get_the_excerpt());
		if (mb_strlen($post_excerpt)>30) {
			echo $post_excerpt;
		} else {
			single_post_title('', true); echo " - "; bloginfo('name');
		}
	} elseif ( is_search() ) {
		bloginfo('name'); echo " で、 SEARCH KEY WORDS ： 「"; the_search_query() ;echo "」 を検索した結果を表示しています。 ";
	} elseif ( is_author() ) {
		bloginfo('name'); echo " の 掲載者名："; echo get_the_author() ;echo " を表示しています。 ";
	} else {
		bloginfo('name'); echo " の "; echo get_the_archive_title() ;echo " を表示しています。 ";
	}
	echo $metadescription_pages;
	?>" />
<?php
}
function pureframe_head() {
if (!empty(get_facebook_appid())) :echo '<head prefix="og: http://ogp.me/ns# fb: http://ogp.me/ns/fb# article: http://ogp.me/ns/article#">'; else: echo '<head>'; endif;
}
function pureframe_ogp() {
if (!empty(get_facebook_appid())) {
?>
<meta property="og:title" content="<?php wp_title( '|', true, 'right' );?>" />
<?php
if ( is_home() || is_front_page() ):echo '<meta property="og:type" content="website" />'; else: echo '<meta property="og:type" content="artcle" />'; endif;
?>
<meta property="og:url" content="<?php echo get_the_permalink(); ?>" />
<meta property="og:image" content="<?php echo get_ogp_image_url(); ?>" />
<meta property="og:site_name" content="<?php echo get_the_title( ); ?>" />
<meta property="og:description" content="<?php if ( is_single() ) {
		$post_excerpt = strip_tags(get_the_excerpt());
		if (mb_strlen($post_excerpt)>30) {
			echo $post_excerpt;
		} else {
			single_post_title('', true);
		}
    } else {
		$post_excerpt = strip_tags(get_the_excerpt());
		if (mb_strlen($post_excerpt)>30) {
			echo $post_excerpt;
		} else {
			bloginfo('name'); echo " - "; bloginfo('description');
		}
	}
	?>" />
<meta property="fb:app_id" content="<?php echo get_facebook_appid(); ?>" />
<?php if (!empty(get_twitter_id())) { ?>
<meta name="twitter:card" content="summarylargeimage" />
<meta name="twitter:site" content="@<?php echo get_twitter_id(); ?>" />
<?php };};
}
function pureframe_analytics() {
if (!empty(get_analytics_id())) {
?>
<script>
window.ga=window.ga||function(){(ga.q=ga.q||[]).push(arguments)};ga.l=+new Date;
ga('create', '<?php echo get_analytics_id() ?>', 'auto');
ga('send', 'pageview');
</script>
<script defer src='https://www.google-analytics.com/analytics.js'></script>
<?php };}

/* remove DNS lookup /dns-prefetch */
add_filter( 'wp_resource_hints', 'remove_dns_prefetch', 10, 2 );
function remove_dns_prefetch( $hints, $relation_type ) {
	if ( 'dns-prefetch' === $relation_type ) {
		return array_diff( wp_dependencies_unique_hosts(), $hints );
	}
	return $hints;
}
/* Wordpress の未使用のヘッダーを整理 */
remove_action( 'wp_head','rsd_link');
remove_action( 'wp_head','wlwmanifest_link');
remove_action( 'wp_head','wp_shortlink_wp_head', 10, 0 );
/* 将来的Embed */
remove_action('wp_head','rest_output_link_wp_head');
remove_action('wp_head','wp_oembed_add_discovery_links');
remove_action('wp_head','wp_oembed_add_host_js');
/* 絵文字削除 */
remove_action('wp_head', 'print_emoji_detection_script', 7);
remove_action('wp_print_styles', 'print_emoji_styles');
/* WordPress バージョンを隠す */
remove_action('wp_head','wp_generator');
foreach ( array( 'rss2_head', 'commentsrss2_head', 'rss_head', 'rdf_header', 'atom_head', 'comments_atom_head', 'opml_head', 'app_head' ) as $action ) {
    remove_action( $action, 'the_generator' );
	}
/* CSS や JS のバージョンを取り除く */
function remove_cssjs_ver( $src ) {
    if( !is_user_logged_in() && strpos( $src, '?ver=' ) )
        $src = remove_query_arg( 'ver', $src );
    return $src;
}
add_filter( 'style_loader_src', 'remove_cssjs_ver', 9999 );
add_filter( 'script_loader_src', 'remove_cssjs_ver', 9999 );
/* デフォルトのgoogle-fontを取り除く */
function remove_wp_open_sans() {
    wp_dequeue_style('cresta-social-googlefonts');
    wp_dequeue_style('open-sans');
    wp_register_style('open-sans', false);
}
add_action( 'wp_enqueue_scripts', 'remove_wp_open_sans', 10);

/* Contact Form 7 を /contactだけで読み込むようにする */
function wpcf7_file_control() {
    add_filter("wpcf7_load_js", "__return_false");
    add_filter("wpcf7_load_css", "__return_false");
    if( is_page("contact") ){
        if( function_exists("wpcf7_enqueue_scripts") ) wpcf7_enqueue_scripts();
        if( function_exists("wpcf7_enqueue_styles") ) wpcf7_enqueue_styles();
    }
}
add_action("template_redirect", "wpcf7_file_control");

/* 構造化データ post-date/time and author. */
function pureframe_posted_on() {
	$time_string = '掲載日: <time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '掲載日: <time class="entry-date published" datetime="%1$s">%2$s</time> / 更新日: <time class="updated" datetime="%3$s">%4$s</time>';
	}
	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);
	$posted_on = sprintf(
		/* translators: %s: post date. esc_html_x( '%s', 'post date', 'pureframe' )*/
		esc_html( '%s', 'post date' ),
		'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
	);
	$byline = sprintf(
		/* translators: %s: post author. */
		esc_html_x( 'by %s', 'post author', 'pureframe' ),
		'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
	);
	echo '<span class="posted-on">' . $posted_on . '</span><span class="byline"> ' . $byline . '</span>'; 
?>
	<div class="entry-title-style">
		<?php if( is_home() || is_front_page() ) { ?>
			<span class="entry-title"><a href="<?php esc_url( get_permalink() ) ?>" rel="bookmark">home</a></span>
		<?php } elseif ( is_single() ) {
			the_title( '<span class="entry-title">', '</span>' );
		} elseif ( is_archive() ) {
			the_archive_title( '<span class="entry-title">', '</span>' );
		} elseif ( is_search() ) {
			?><span class="entry-title"><?php the_search_query();?> で検索した結果</span><?php
		} else {
			the_title( '<span class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></span>' );
		}
		?>
	</div>
	<?php 
}
/* canonicalの正規表記 */
remove_action('wp_head', 'adjacent_posts_rel_link_wp_head');
remove_action('wp_head', 'rel_canonical');
add_action( 'wp_head', 'add_canonical' );
function add_canonical() {
	global $max_page, $page, $paged, $wp_query;
	if (is_home()||is_front_page()) {
		$canonical = home_url();
	} elseif (is_category()) {
		$canonical = get_category_link(get_query_var('cat'));
	} elseif (is_page() || is_single()) { 
		$canonical = get_permalink();
		if ( $paged >= 2 || $page >= 2) :
			$canonical = $canonical.'page/'.max( $paged, $page ).'/';
		endif;
	} elseif (is_search()){
		$encode_s_word = urlencode(get_search_query());
		$canonical = home_url().'?s='.$encode_s_word;
	} elseif(is_tag()){
		$encode_tag = urlencode(single_tag_title( '', false ));
		$canonical = home_url().'/archives/tag/'.$encode_tag;
	} elseif(is_404()) {
		$canonical =  home_url()."/404";
	} else {
		$canonical  =  null;
	} 
	if ($canonical == !null) {
		echo '<link rel="canonical" href="'.$canonical.'">'."\n";
	}
	
	if (!$max_page)
		$max_page = $wp_query->max_num_pages;
	if (!$paged)
		$paged = 1;
		$nextpage = intval($paged) + 1;
	if (!is_singular() && ($nextpage <= $max_page)) { 
		echo '<link rel="next" href="'; echo next_posts( $max_page, false ); echo '" />';
	}
	if(!is_singular() && $paged > 1){
		echo '<link rel="prev" href="'; echo previous_posts( false ); echo '" />';
	}
}
/* TinyMCEのフォントとスタイル適用 */
function pureframe_tinyMCE($arr){
	$arr['font_formats'] =
        "Helvetica='Helvetica';".
        "Century Gothic='Century Gothic';".
        "Franklin Gothic Medium='Franklin Gothic Medium';".
        "Gulim='Gulim';".
        "Impact='Impact';".
        "Verdana='Verdana';".
        "Georgia='Georgia';".
        "Palatino='Palatino';".
        "Times New Roman='Times New Roman';".
        "Courier New='Courier New';".
        "Comic Sans MS='Comic Sans MS';".
        "ヒラギノ角ゴ='ヒラギノ角ゴ Pro W3','Hiragino Kaku Gothic Pro','ヒラギノ角ゴ ProN W3','Hiragino Kaku Gothic ProN';".
        "ヒラギノ丸ゴ='ヒラギノ丸ゴ Pro W4','Hiragino Maru Gothic Pro','ヒラギノ丸ゴ ProN W4','Hiragino Maru Gothic ProN';".
        "ＭＳ Ｐゴシック='ＭＳ Ｐゴシック','MS PGothic';".
        "ＭＳ ゴシック='ＭＳ ゴシック','MS Gothic';".
        "游ゴシック='游ゴシック','Yu Gothic';".
        "ヒラギノ明朝='ヒラギノ明朝 Pro W3','Hiragino Mincho Pro',ヒラギノ明朝 ProN W3','Hiragino Mincho ProN';".
        "ＭＳ Ｐ明朝='ＭＳ Ｐ明朝','MS PMincho';".
        "ＭＳ 明朝='ＭＳ 明朝','MS Mincho';".
        "游明朝='游明朝','Yu Mincho';".
        "游明朝体='游明朝体','YuMincho';"
        ;
     $style_formats = [
		[
            'title'    => 'Source List[整形済]',
            'selector' => 'pre',
            'classes'  => 'source'],
		[
            'title'    => 'Responsive Images',
            'selector' => 'img',
            'classes'  => 'pure-img'],
        [
            'title'    => 'Default Table',
            'selector' => 'table',
            'classes'  => 'pure-table'],
		[
            'title'    => 'Bordered Table',
            'selector' => 'table',
            'classes'  => 'pure-table pure-table-bordered'],
		[
            'title'    => 'Table with Horizontal Borders',
            'selector' => 'table',
            'classes'  => 'pure-table pure-table-horizontal'],
		[
            'title'    => 'Striped Table',
            'selector' => 'table',
            'classes'  => 'pure-table pure-table-striped'],
		[
            'title'    => 'Striped Table tr',
            'selector' => 'tr',
            'classes'  => 'pure-table-odd'],
		[
            'title'    => 'Default Buttons',
            'selector' => 'a',
            'classes'  => 'pure-button'],
		[
            'title'    => 'Primary Buttons',
            'selector' => 'a',
            'classes'  => 'pure-button pure-button-primary']
    ];
    $arr['style_formats'] = json_encode($style_formats);
    return $arr;
}
add_filter('tiny_mce_before_init','pureframe_tinyMCE',1000);
/* TinyMCEへのスタイル適用のおまじない */
function extend_tiny_mce_before_init( $mce_init ) {
 
    $mce_init['cache_suffix'] = 'v='.time();
 
    return $mce_init;    
}
add_filter( 'tiny_mce_before_init', 'extend_tiny_mce_before_init' );

/**
 * Widget API: WP_Widget_Recent_Posts class
 *
 * @package WordPress
 * @subpackage Widgets
 * @since 4.4.0
 */

/**
 * Core class used to implement a Recent Posts widget.
 *
 * @since 2.8.0
 *
 * @see WP_Widget
 */
class WP_Widget_Recent_private_blog extends WP_Widget {

	/**
	 * Sets up a new Recent Posts widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 */
	function __construct() {
		$widget_ops = array(
			'classname' => 'widget_recent_info_entries',
			'description' => '直近のブログ',
			'customize_selective_refresh' => true,
		);
		parent::__construct( 'recent-informations','最近のブログ', $widget_ops );
		$this->alt_option_name = 'widget_recent_info_entries';
	}

	/**
	 * Outputs the content for the current Recent Posts widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the current Recent Posts widget instance.
	 */
	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : '最近のブログ';

		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;
		if ( ! $number )
			$number = 5;
		$show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;

		/**
		 * Filters the arguments for the Recent Posts widget.
		 *
		 * @since 3.4.0
		 *
		 * @see WP_Query::get_posts()
		 *
		 * @param array $args An array of arguments used to retrieve the recent posts.
		 */
		$r = new WP_Query( apply_filters( 'widget_posts_args', array(
			"post_type" => "private_blog",
			'posts_per_page'      => $number,
			'no_found_rows'       => true,
			'post_status'         => 'publish',
			'ignore_sticky_posts' => true
		) ) );

		if ($r->have_posts()) :
		?>
		<?php echo $args['before_widget']; ?>
		<?php if ( $title ) {
			echo $args['before_title'] . $title . $args['after_title'];
		} ?>
		<ul>
		<?php while ( $r->have_posts() ) : $r->the_post(); ?>
			<li>
				<a href="<?php the_permalink(); ?>"><?php get_the_title() ? the_title() : the_ID(); ?></a>
			<?php if ( $show_date ) : ?>
				<span class="post-date"><?php echo get_the_date(); ?></span>
			<?php endif; ?>
			</li>
		<?php endwhile; ?>
		</ul>
		<?php echo $args['after_widget']; ?>
		<?php
		// Reset the global $the_post as this query will have stomped on it
		wp_reset_postdata();

		endif;
	}

	/**
	 * Handles updating the settings for the current Recent Posts widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Updated settings to save.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = sanitize_text_field( $new_instance['title'] );
		$instance['number'] = (int) $new_instance['number'];
		$instance['show_date'] = isset( $new_instance['show_date'] ) ? (bool) $new_instance['show_date'] : false;
		return $instance;
	}

	/**
	 * Outputs the settings form for the Recent Posts widget.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {
		$title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		$show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
?>
		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of posts to show:' ); ?></label>
		<input class="tiny-text" id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="number" step="1" min="1" value="<?php echo $number; ?>" size="3" /></p>

		<p><input class="checkbox" type="checkbox"<?php checked( $show_date ); ?> id="<?php echo $this->get_field_id( 'show_date' ); ?>" name="<?php echo $this->get_field_name( 'show_date' ); ?>" />
		<label for="<?php echo $this->get_field_id( 'show_date' ); ?>"><?php _e( 'Display post date?' ); ?></label></p>
<?php
	}
}
// WP_Widget_Recent_private_blog ウィジェットを登録
function register_private_blog_widget() {
    register_widget( 'WP_Widget_Recent_private_blog' );
}
add_action( 'widgets_init', 'register_private_blog_widget' );

/**
 * Widget API: WP_Widget_Archives class
 *
 * @package WordPress
 * @subpackage Widgets
 * @since 4.4.0
 */

/**
 * Core class used to implement the Archives widget.
 *
 * @since 2.8.0
 *
 * @see WP_Widget
 */
class WP_Widget_Info_Archives extends WP_Widget {

	/**
	 * Sets up a new Archives widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 */
	function __construct() {
		$widget_ops = array(
			'classname' => 'widget_info_archive',
			'description' => 'ブログの月別アーカイブ',
			'customize_selective_refresh' => true,
		);
		parent::__construct('information&#8217;s archives', 'ブログ アーカイブ', $widget_ops);
	}

	/**
	 * Outputs the content for the current Archives widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the current Archives widget instance.
	 */
	public function widget( $args, $instance ) {
		$c = ! empty( $instance['count'] ) ? '1' : '0';
		$d = ! empty( $instance['dropdown'] ) ? '1' : '0';

		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? 'アーカイブ' : $instance['title'], $instance, $this->id_base );

		echo $args['before_widget'];
		if ( $title ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		if ( $d ) {
			$dropdown_id = "{$this->id_base}-dropdown-{$this->number}";
			?>
		<label class="screen-reader-text" for="<?php echo esc_attr( $dropdown_id ); ?>"><?php echo $title; ?></label>
		<select id="<?php echo esc_attr( $dropdown_id ); ?>" name="archive-dropdown" onchange='document.location.href=this.options[this.selectedIndex].value;'>
			<?php
			/**
			 * Filters the arguments for the Archives widget drop-down.
			 *
			 * @since 2.8.0
			 *
			 * @see wp_get_archives()
			 *
			 * @param array $args An array of Archives widget drop-down arguments.
			 */
			$dropdown_args = apply_filters( 'widget_archives_dropdown_args', array(
				"post_type" => "private_blog",
				'type'            => 'monthly',
				'format'          => 'option',
				'show_post_count' => $c
			) );

			switch ( $dropdown_args['type'] ) {
				case 'yearly':
					$label = __( 'Select Year' );
					break;
				case 'monthly':
					$label = __( 'Select Month' );
					break;
				case 'daily':
					$label = __( 'Select Day' );
					break;
				case 'weekly':
					$label = __( 'Select Week' );
					break;
				default:
					$label = __( 'Select Post' );
					break;
			}
			?>

			<option value=""><?php echo esc_attr( $label ); ?></option>
			<?php wp_get_archives( $dropdown_args ); ?>

		</select>
		<?php } else { ?>
		<ul>
		<?php
		/**
		 * Filters the arguments for the Archives widget.
		 *
		 * @since 2.8.0
		 *
		 * @see wp_get_archives()
		 *
		 * @param array $args An array of Archives option arguments.
		 */
		wp_get_archives( apply_filters( 'widget_archives_args', array(
			"post_type" => "private_blog",
			'type'            => 'monthly',
			'show_post_count' => $c
		) ) );
		?>
		</ul>
		<?php
		}

		echo $args['after_widget'];
	}

	/**
	 * Handles updating settings for the current Archives widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget_Archives::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Updated settings to save.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$new_instance = wp_parse_args( (array) $new_instance, array( 'title' => '', 'count' => 0, 'dropdown' => '') );
		$instance['title'] = sanitize_text_field( $new_instance['title'] );
		$instance['count'] = $new_instance['count'] ? 1 : 0;
		$instance['dropdown'] = $new_instance['dropdown'] ? 1 : 0;

		return $instance;
	}

	/**
	 * Outputs the settings form for the Archives widget.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'count' => 0, 'dropdown' => '') );
		$title = sanitize_text_field( $instance['title'] );
		?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label> <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>
		<p>
			<input class="checkbox" type="checkbox"<?php checked( $instance['dropdown'] ); ?> id="<?php echo $this->get_field_id('dropdown'); ?>" name="<?php echo $this->get_field_name('dropdown'); ?>" /> <label for="<?php echo $this->get_field_id('dropdown'); ?>"><?php _e('Display as dropdown'); ?></label>
			<br/>
			<input class="checkbox" type="checkbox"<?php checked( $instance['count'] ); ?> id="<?php echo $this->get_field_id('count'); ?>" name="<?php echo $this->get_field_name('count'); ?>" /> <label for="<?php echo $this->get_field_id('count'); ?>"><?php _e('Show post counts'); ?></label>
		</p>
		<?php
	}
}
// WP_Widget_Info_Archives ウィジェットを登録
function register_private_blog_Archives_widget() {
    register_widget( 'WP_Widget_Info_Archives' );
}
add_action( 'widgets_init', 'register_private_blog_Archives_widget' );


?>